# events/www/admin/event-add.tcl

ad_page_contract {
    Purpose: Allow an admin to select a venue for a new event, or
    add a new venue if necessary first.

    @param activity_id the activity to which we're adding an event

    @author Michael Steigman (michael@steigman.net)
    @author Bryan Che (bryanche@arsdigita.com)
    @cvs_id $Id: event-add.tcl,v 1.1 2004/11/23 20:05:54 annyf Exp $
} {
    {activity_id:integer,notnull}
}
set package_id [ad_conn package_id]
set user_id [ad_conn user_id]

#see if user have admin permission for the package
set permission_admin [permission::permission_p -object_id $package_id -party_id $user_id  -privilege "admin"]
set permission_create [permission::permission_p -object_id $package_id -party_id $user_id  -privilege "create"]
if { $permission_admin != 1 && $permission_create != 1} {

    doc_return 200 text/html  "<h3>Permission Denied</h3>
                               You don't have permission to admin Events Management. "
    ad_script_abort
}


set venues [events::venue::venues_get_options]

if {[llength $venues] == 0} {
    set no_venues 1
} else {
    set no_venues 0
}

form create venue_select -action event-add-2

element create venue_select activity_id \
    -label "Activity ID" \
    -datatype text \
    -widget hidden \
    -value $activity_id

element create venue_select venue_id \
    -label "Select a venue for your new event" \
    -datatype text \
    -widget select \
    -options $venues

events::activity::get -activity_id $activity_id -array activity_info
set context [list [list "activities" Activities] [list "activity?[export_vars { activity_id }]" $activity_info(name)] "Add Event"]
set activity_name $activity_info(name)
set title "Add a New Event for $activity_name"
set return_url "event-add-2?activity_id=$activity_id"
