# events/www/admin/event-toggle-available-p.tcl

ad_page_contract {
    Toggles the availability of an event.

    @param event_id the event whose availability we're toggling

    @author Bryan Che (bryanche@arsdigita.com)
    @cvs_id $Id: event-toggle-available-p.tcl,v 1.1 2004/11/23 20:05:54 annyf Exp $
} {
    {event_id:integer,notnull}
} -validate {
    event_exists_p -requires {event_id} { 
	if { ![events::event::exists_p -event_id $event_id] } {
	    ad_complain "We couldn't find the event you asked for."
	    return 0
	}
	return 1
    }
}
set user_id [ad_conn user_id]
set package_id [ad_conn package_id]
set package_admin [permission::permission_p -object_id $package_id -party_id $user_id -privilege "admin"]
set permission_create [permission::permission_p -object_id $package_id -party_id $user_id -privilege "create"]
set event_admin [permission::permission_p -object_id $event_id -party_id $user_id -privilege "admin"]

if { $package_admin != 1 && $permission_create != 1 && $event_admin != 1} {
    doc_return 200 text/html  "<h3>Permission Denied</h3>
                               You don't have permission to admin Events Management. "
    ad_script_abort
}

db_transaction {

    events::event::toggle_available_p -event_id $event_id
    
    events::event::get -event_id $event_id -array event_info

    if { [db_0or1row select_ecommerce_info {}] } {
	set user_id [ad_get_user_id]
	set peeraddr [ns_conn peeraddr]
	
	db_dml toggle_active_p_update {}
    }

}

ad_returnredirect "event?event_id=$event_id"