# events/www/admin/venue-delete.tcl

ad_page_contract {
    deletes a venue

    @param venue_id the venue to be deleted

    @author Michael Steigman (michael@steigman.net)
    @author Bryan Che (bryanche@arsdigita.com)
    @cvs_id $Id: venue-delete.tcl,v 1.1 2004/11/23 20:05:54 annyf Exp $
} {
    {venue_id:integer,notnull}
} -validate {
    exists_p -requires {venue_id} { 
	if { ![events::venue::exists_p -venue_id $venue_id] } {
	    ad_complain "We couldn't find the venue you specified."
	    return 0
	}
	return 1
    }
    in_use_p -requires {venue_id} {
	if { [events::venue::in_use_p -venue_id $venue_id] } {
	    ad_complain "This venue is being
	    used by one or more events.  You cannot delete this
	    venue unless no events are located there."
	    return 0
	}
	return 1
    }
}
set user_id [ad_conn user_id]
set package_id [ad_conn package_id]
set package_admin [permission::permission_p -object_id $package_id -party_id $user_id -privilege "admin"]


if { $package_admin != 1} {

    doc_return 200 text/html  "<h3>Permission Denied</h3>
                               You don't have permission to admin Events Management. "
    ad_script_abort
}


events::venue::delete -venue_id $venue_id

ad_returnredirect "venues"

